==> extended_text_editing_controllers-0.0.4.tar.gz: test/double_text_editing_controller_test.dart <==
import 'package:flutter_test/flutter_test.dart';

import '../lib/plugin.dart';

String reason(String input, String output) {
  return '"$input" -> "$output"';
}

void main() {
  test('Check controller for different initial values', () {
    final inputValues = <String>[
      '1',
      '3.14',
      '3.14.',
      '3,14',
      '3,,14',
      '3.14,',
      '3,14,14',
      '3 14',
    ];
    final outputValues = <String>[
      '1',
      '3.14',
      '',
      '3.14',
      '3.14',
      '',
      '',
      '314',
    ];
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      final controller = DoubleTextEditingController();
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index], reason: reason(value, outputValues[index]));
    }
  });
  test('Check controller for serial input', () {
    final inputValues = <String>[
      '3',
      '3,',
      '3.1',
      '3.1,',
      '3.1,5',
      '32',
    ];
    final outputValues = <String>[
      '3',
      '3.',
      '3.1',
      '3.1',
      '3.1',
      '32',
    ];
    final controller = DoubleTextEditingController();
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index], reason: reason(value, outputValues[index]));
    }
  });
  test('Check controller for serial incorrect values', () {
    final inputValues = <String>[
      'a',
      '3',
      '3a',
      '3,a',
    ];
    final outputValues = <String>[
      '',
      '3',
      '3',
      '3.',
    ];
    final controller = DoubleTextEditingController();
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index], reason: reason(value, outputValues[index]));
    }
  });
}

==> extended_text_editing_controllers-1.0.1.tar.gz: test/double_text_editing_controller_test.dart <==
import 'package:flutter_test/flutter_test.dart';

import '../lib/plugin.dart';

String reason(String input, String output) {
  return '"$input" -> "$output"';
}

void main() {
  test('Check controller for different initial values', () {
    final inputValues = <String>[
      '1',
      '3.14',
      '3.14.',
      '3,14',
      '3,,14',
      '3.14,',
      '3,14,14',
      '3 14',
    ];
    final outputValues = <String>[
      '1',
      '3.14',
      '',
      '3.14',
      '3.14',
      '',
      '',
      '314',
    ];
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      final controller = DoubleTextEditingController();
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index],
          reason: reason(value, outputValues[index]));
    }
  });
  test('Check controller for serial input', () {
    final inputValues = <String>[
      '3',
      '3,',
      '3.1',
      '3.1,',
      '3.1,5',
      '32',
    ];
    final outputValues = <String>[
      '3',
      '3.',
      '3.1',
      '3.1',
      '3.1',
      '32',
    ];
    final controller = DoubleTextEditingController();
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index],
          reason: reason(value, outputValues[index]));
    }
  });
  test('Check controller for serial incorrect values', () {
    final inputValues = <String>[
      'a',
      '3',
      '3a',
      '3,a',
    ];
    final outputValues = <String>[
      '',
      '3',
      '3',
      '3.',
    ];
    final controller = DoubleTextEditingController();
    for (int index = 0; index < inputValues.length; index++) {
      final String value = inputValues[index];
      controller.value = TextEditingValue(text: value);
      expect(controller.text, outputValues[index],
          reason: reason(value, outputValues[index]));
    }
  });
}
